@@ -31,13 +31,13 @@ struct dnsthread_internal {
 	int res_errno;		/* Errno to be passed back on failure. */
 
 	/* Callback to occur when resolution is complete. */
-	int (*callback)(void *, struct sock_addr **);	/* Callback. */
+	int (* callback)(void *, struct sock_addr **);	/* Callback. */
 	void * cookie;		/* Cookie. */
 };
 
 /* Cookie used by dnsthread_resolve. */
 struct resolve_cookie {
-	int (*callback)(void *, struct sock_addr **);
+	int (* callback)(void *, struct sock_addr **);
 	void * cookie;
 	DNSTHREAD T;
 };
@@ -125,8 +125,10 @@ workthread(void * cookie)
 	} while (1);
 
 	/* Close the socket pair. */
-	close(T->wakeupsock[1]);
-	close(T->wakeupsock[0]);
+	if (close(T->wakeupsock[1]))
+		warnp("close");
+	if (close(T->wakeupsock[0]))
+		warnp("close");
 
 	/* Destroy the condition variable. */
 	if ((rc = pthread_cond_destroy(&T->cv)) != 0) {
@@ -209,8 +211,10 @@ dnsthread_spawn(void)
 	return (T);
 
 err5:
-	close(T->wakeupsock[1]);
-	close(T->wakeupsock[0]);
+	if (close(T->wakeupsock[1]))
+		warnp("close");
+	if (close(T->wakeupsock[0]))
+		warnp("close");
 err4:
 	pthread_cond_destroy(&T->cv);
 err3:
@@ -255,7 +259,7 @@ dnsthread_resolveone(DNSTHREAD T, const char * addr,
 
 	/* Duplicate the address to be resolved. */
 	if ((T->addr = strdup(addr)) == NULL)
-	    goto err1;
+		goto err1;
 
 	/* Remember what callback we'll need to do eventually. */
 	T->callback = callback;
@@ -306,7 +310,7 @@ callback_resolveone(void * cookie)
 	struct sock_addr ** sas;
 	uint8_t zero;
 	int res_errno = 0;
-	int (*callback)(void *, struct sock_addr **);
+	int (* callback)(void *, struct sock_addr **);
 	void * cb_cookie;
 	int rc;
 
