@@ -8,16 +8,16 @@ if [ -z "${CC}" ]; then
 	echo "\$CC is not defined!  Cannot run any compiler tests." 1>&2
 	exit 1
 fi
-if ! [ ${PATH} = "$1" ]; then
-	echo "WARNING: POSIX violation: $SHELL's command -p resets \$PATH" 1>&2
+if ! [ "${PATH}" = "$1" ]; then
+	echo "WARNING: POSIX violation: ${SHELL}'s command -p resets \$PATH" 1>&2
 	PATH=$1
 fi
 
 # Find directory of this script and the source files
-D=$(dirname $0)
+D=$(dirname "$0")
 
-if ! ${CC} -O2 $D/posix-cflags-filter.c 2>/dev/null; then
-	if ${CC} $D/posix-cflags-filter.c 2>/dev/null; then
+if ! ${CC} -O2 "${D}/posix-trivial.c" 2>/dev/null; then
+	if ${CC} "${D}/posix-trivial.c" 2>/dev/null; then
 		echo 'CFLAGS_FILTERED=""'
 		echo 'for OPT in $CFLAGS; do'
 		echo '	if [ "$OPT" = "-O2" ]; then'
