@@ -1,3 +1,7 @@
+/**
+ * APISUPPORT CFLAGS: LIBCRYPTO_LOW_LEVEL_AES
+ */
+
 #include <assert.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -67,7 +71,7 @@ static struct aes_test {
 
 /* Test a function against test vectors. */
 static int
-functest(int(* func)(const uint8_t *, size_t, const uint8_t[16], uint8_t[16]))
+functest(int (* func)(const uint8_t *, size_t, const uint8_t[16], uint8_t[16]))
 {
 	struct aes_test * knowngood;
 	uint8_t ctext[16];
@@ -99,13 +103,14 @@ err0:
 
 #if defined(CPUSUPPORT_X86_AESNI)
 static int
-x86_aesni_oneshot(const uint8_t * key, size_t len, const uint8_t ptext[16],
-    uint8_t ctext[16])
+x86_aesni_oneshot(const uint8_t * key_unexpanded, size_t len,
+    const uint8_t ptext[16], uint8_t ctext[16])
 {
 	void * kexp_hw;
 
 	/* Expand the key and encrypt with hardware intrinsics. */
-	if ((kexp_hw = crypto_aes_key_expand_aesni(key, len)) == NULL)
+	if ((kexp_hw = crypto_aes_key_expand_aesni(key_unexpanded, len))
+	    == NULL)
 		goto err0;
 	crypto_aes_encrypt_block_aesni(ptext, ctext, kexp_hw);
 	crypto_aes_key_free_aesni(kexp_hw);
@@ -121,12 +126,12 @@ err0:
 
 #if defined(CPUSUPPORT_ARM_AES)
 static int
-arm_aes_oneshot(const uint8_t * key, size_t len, const uint8_t ptext[16],
-    uint8_t * ctext)
+arm_aes_oneshot(const uint8_t * key_unexpanded, size_t len,
+    const uint8_t ptext[16], uint8_t * ctext)
 {
 	void * kexp_hw;
 
-	if ((kexp_hw = crypto_aes_key_expand_arm(key, len)) == NULL)
+	if ((kexp_hw = crypto_aes_key_expand_arm(key_unexpanded, len)) == NULL)
 		goto err0;
 	crypto_aes_encrypt_block_arm(ptext, ctext, kexp_hw);
 	crypto_aes_key_free_arm(kexp_hw);
@@ -141,17 +146,24 @@ err0:
 #endif
 
 static int
-openssl_oneshot(const uint8_t * key, size_t len, const uint8_t ptext[16],
-    uint8_t * ctext)
+openssl_oneshot(const uint8_t * key_unexpanded, size_t len,
+    const uint8_t ptext[16], uint8_t * ctext)
 {
-	AES_KEY kexp;
+	AES_KEY kexp_actual;
+	AES_KEY * kexp = &kexp_actual;
 
 	/* Expand the key, encrypt, and clean up. */
-	AES_set_encrypt_key(key, (int)(len * 8), &kexp);
-	AES_encrypt(ptext, ctext, &kexp);
-	insecure_memzero(&kexp, sizeof(AES_KEY));
+	if (AES_set_encrypt_key(key_unexpanded, (int)(len * 8), kexp) != 0)
+		goto err0;
+	AES_encrypt(ptext, ctext, kexp);
+	insecure_memzero(kexp, sizeof(AES_KEY));
 
+	/* Success! */
 	return (0);
+
+err0:
+	/* Failure! */
+	return (-1);
 }
 
 /* Which type of hardware acceleration should we use, if any? */
@@ -215,12 +227,13 @@ crypto_aes_can_use_intrinsics(void)
 }
 
 /**
- * crypto_aes_key_expand(key, len):
- * Expand the ${len}-byte AES key ${key} into a structure which can be passed
- * to crypto_aes_encrypt_block().  The length must be 16 or 32.
+ * crypto_aes_key_expand(key_unexpanded, len):
+ * Expand the ${len}-byte unexpanded AES key ${key_unexpanded} into a
+ * structure which can be passed to crypto_aes_encrypt_block().  The length
+ * must be 16 or 32.
  */
 struct crypto_aes_key *
-crypto_aes_key_expand(const uint8_t * key, size_t len)
+crypto_aes_key_expand(const uint8_t * key_unexpanded, size_t len)
 {
 	AES_KEY * kexp;
 
@@ -233,11 +246,11 @@ crypto_aes_key_expand(const uint8_t * key, size_t len)
 
 #ifdef CPUSUPPORT_X86_AESNI
 	if (hwaccel == HW_X86_AESNI)
-		return (crypto_aes_key_expand_aesni(key, len));
+		return (crypto_aes_key_expand_aesni(key_unexpanded, len));
 #endif
 #ifdef CPUSUPPORT_ARM_AES
 	if (hwaccel == HW_ARM_AES)
-		return (crypto_aes_key_expand_arm(key, len));
+		return (crypto_aes_key_expand_arm(key_unexpanded, len));
 #endif
 #endif /* HWACCEL */
 
@@ -246,11 +259,14 @@ crypto_aes_key_expand(const uint8_t * key, size_t len)
 		goto err0;
 
 	/* Expand the key. */
-	AES_set_encrypt_key(key, (int)(len * 8), kexp);
+	if (AES_set_encrypt_key(key_unexpanded, (int)(len * 8), kexp) != 0)
+		goto err1;
 
 	/* Success! */
 	return ((void *)kexp);
 
+err1:
+	free(kexp);
 err0:
 	/* Failure! */
 	return (NULL);
