@@ -1,5 +1,5 @@
-#ifndef _EVENTS_INTERNAL_H_
-#define _EVENTS_INTERNAL_H_
+#ifndef EVENTS_INTERNAL_H_
+#define EVENTS_INTERNAL_H_
 
 #include <sys/time.h>
 
@@ -35,7 +35,8 @@ struct eventrec * events_immediate_get(void);
  * stored in ${tv} may be modified.  If ${*interrupt_requested} is non-zero
  * and a signal is received, exit.
  */
-int events_network_select(struct timeval *, volatile sig_atomic_t *);
+int events_network_select(const struct timeval *,
+    const volatile sig_atomic_t *);
 
 /**
  * events_network_selectstats_startclock(void):
@@ -81,4 +82,4 @@ int events_timer_min(struct timeval **);
  */
 int events_timer_get(struct eventrec **);
 
-#endif /* !_EVENTS_INTERNAL_H_ */
+#endif /* !EVENTS_INTERNAL_H_ */
