@@ -1,6 +1,7 @@
-#ifndef _IMALLOC_H_
-#define _IMALLOC_H_
+#ifndef IMALLOC_H_
+#define IMALLOC_H_
 
+#include <assert.h>
 #include <errno.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -8,17 +9,25 @@
 /**
  * imalloc(nrec, reclen):
  * Allocate ${nrec} records of length ${reclen}.  Check for size_t overflow.
+ * ${reclen} must not be zero.  If ${nrec} is zero, return NULL.
  */
 static inline void *
 imalloc(size_t nrec, size_t reclen)
 {
 
+	/* Sanity check. */
+	assert(reclen != 0);
+
+	/* Handle cases where we don't allocate memory. */
+	if (nrec == 0)
+		return (NULL);
 	if (nrec > SIZE_MAX / reclen) {
 		errno = ENOMEM;
 		return (NULL);
-	} else {
-		return (malloc(nrec * reclen));
 	}
+
+	/* Allocate memory. */
+	return (malloc(nrec * reclen));
 }
 
 /**
@@ -30,4 +39,4 @@ imalloc(size_t nrec, size_t reclen)
 	((((p) = (type *)imalloc((nrec), sizeof(type))) == NULL) &&	\
 	    ((nrec) > 0))
 
-#endif /* !_IMALLOC_H_ */
+#endif /* !IMALLOC_H_ */
