@@ -1,5 +1,5 @@
-#ifndef _PERFTESTS_H_
-#define _PERFTESTS_H_
+#ifndef PERFTESTS_H_
+#define PERFTESTS_H_
 
 #include <stddef.h>
 #include <stdint.h>
@@ -17,11 +17,13 @@
  * where ${buffer} is large enough to hold the maximum buffer size.  Print
  * the time and speed of processing each buffer size.  ${init_func} and
  * ${clean_func} may be NULL.  If ${init_func} has completed successfully,
- * then ${clean_func} will be called if there is a subsequent error.
+ * then ${clean_func} will be called if there is a subsequent error.  If
+ * ${nbytes_warmup} is 0, then don't perform an initial ${init_func} &&
+ * ${func} && ${clean_func}.
  */
 int perftest_buffers(size_t, const size_t *, size_t, size_t, int,
     int (*)(void *, uint8_t *, size_t),
     int (*)(void *, uint8_t *, size_t, size_t),
     int (*)(void *), void *);
 
-#endif /* !_PERFTESTS_H_ */
+#endif /* !PERFTESTS_H_ */
