@@ -18,14 +18,14 @@ scenario_cmd() {
 	setup_spiped_encryption_server
 
 	# Open and close a connection, keeping it open for 2 seconds.
-	setup_check_variables "open 2 seconds close"
+	setup_check "open 2 seconds close"
 	(
 		( echo "" ; sleep 2 ) |		\
-			 ${nc_client_binary} ${src_sock}
-		echo $? > ${c_exitfile}
+			 ${nc_client_binary} "${src_sock}"
+		echo $? > "${c_exitfile}"
 		touch "${flag_1}"
 	) &
-	wait_for_file "${flag_1}"
+	wait_while 0 test ! -e "${flag_1}"
 
 	# Wait for server(s) to quit.
 	servers_stop
